# Generated by Django 3.2 on 2022-06-15 07:29

import wagtail.embeds.blocks
import wagtail.images.blocks
from django.db import migrations
from wagtail import VERSION as WAGTAIL_VERSION

import wagtail.blocks as wagtail_blocks
import wagtail.fields as wagtail_fields


class Migration(migrations.Migration):

    dependencies = [
        ("wagtail_guide", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="editorguide",
            name="sections",
            field=wagtail_fields.StreamField(
                [
                    (
                        "heading",
                        wagtail_blocks.CharBlock(
                            form_classname="full title",
                            icon="title",
                            template="wagtail_guide/streamfield/blocks/heading_block.html",
                        ),
                    ),
                    (
                        "paragraph",
                        wagtail_blocks.RichTextBlock(
                            features=[
                                "h2",
                                "h3",
                                "h4",
                                "h5",
                                "h6",
                                "bold",
                                "italic",
                                "link",
                                "ul",
                                "ol",
                                "hr",
                            ]
                        ),
                    ),
                    (
                        "image",
                        wagtail_blocks.StructBlock(
                            [
                                ("image", wagtail.images.blocks.ImageChooserBlock()),
                                ("caption", wagtail_blocks.CharBlock(required=False)),
                            ]
                        ),
                    ),
                    (
                        "quote",
                        wagtail_blocks.StructBlock(
                            [
                                (
                                    "quote",
                                    wagtail_blocks.CharBlock(form_classname="title"),
                                ),
                                (
                                    "attribution",
                                    wagtail_blocks.CharBlock(required=False),
                                ),
                            ]
                        ),
                    ),
                    (
                        "pull_quote",
                        wagtail_blocks.StructBlock(
                            [
                                (
                                    "pull_quote",
                                    wagtail_blocks.CharBlock(form_classname="title"),
                                )
                            ]
                        ),
                    ),
                    (
                        "embed",
                        wagtail_blocks.StructBlock(
                            [
                                ("title", wagtail_blocks.CharBlock(required=False)),
                                ("embed", wagtail.embeds.blocks.EmbedBlock()),
                            ]
                        ),
                    ),
                    (
                        "video",
                        wagtail_blocks.StructBlock(
                            [
                                (
                                    "video",
                                    wagtail.embeds.blocks.EmbedBlock(
                                        label="Video URL", required=False
                                    ),
                                )
                            ]
                        ),
                    ),
                ],
                use_json_field=True,
                blank=True,
            )
            if WAGTAIL_VERSION >= (3, 0)
            else wagtail_fields.StreamField(
                [
                    (
                        "heading",
                        wagtail_blocks.CharBlock(
                            form_classname="full title",
                            icon="title",
                            template="wagtail_guide/streamfield/blocks/heading_block.html",
                        ),
                    ),
                    (
                        "paragraph",
                        wagtail_blocks.RichTextBlock(
                            features=[
                                "h2",
                                "h3",
                                "h4",
                                "h5",
                                "h6",
                                "bold",
                                "italic",
                                "link",
                                "ul",
                                "ol",
                                "hr",
                            ]
                        ),
                    ),
                    (
                        "image",
                        wagtail_blocks.StructBlock(
                            [
                                ("image", wagtail.images.blocks.ImageChooserBlock()),
                                ("caption", wagtail_blocks.CharBlock(required=False)),
                            ]
                        ),
                    ),
                    (
                        "quote",
                        wagtail_blocks.StructBlock(
                            [
                                (
                                    "quote",
                                    wagtail_blocks.CharBlock(form_classname="title"),
                                ),
                                (
                                    "attribution",
                                    wagtail_blocks.CharBlock(required=False),
                                ),
                            ]
                        ),
                    ),
                    (
                        "pull_quote",
                        wagtail_blocks.StructBlock(
                            [
                                (
                                    "pull_quote",
                                    wagtail_blocks.CharBlock(form_classname="title"),
                                )
                            ]
                        ),
                    ),
                    (
                        "embed",
                        wagtail_blocks.StructBlock(
                            [
                                ("title", wagtail_blocks.CharBlock(required=False)),
                                ("embed", wagtail.embeds.blocks.EmbedBlock()),
                            ]
                        ),
                    ),
                    (
                        "video",
                        wagtail_blocks.StructBlock(
                            [
                                (
                                    "video",
                                    wagtail.embeds.blocks.EmbedBlock(
                                        label="Video URL", required=False
                                    ),
                                )
                            ]
                        ),
                    ),
                ],
                blank=True,
            ),
        ),
    ]



from django.shortcuts import render
from wagtail.models import Site

from .models import EditorGuide


def index(request):
    # There should only ever be one instance of the guide
    # But we need to check the site incase there is a 'per' site guide
    # On a multisite setup
    content = (
        EditorGuide.objects.all().filter(site=Site.find_for_request(request)).first()
    )

    # Send a boolean to populate a menu if there are more than
    # one 'heading' block type.
    nav = False
    if content:
        if (
            len([i.block_type for i in content.sections if i.block_type == "heading"])
            > 1
        ):
            nav = True

    return render(request, "wagtail_guide/base.html", {"content": content, "nav": nav})



from django.conf import settings


class WagtailGuideSettings:
    def __init__(self, defaults=None):
        self.defaults = {
            "ADD_WAGTAIL_GUIDE_TO_HELP_MENU": False,
            "WAGTAIL_GUIDE_MENU_LABEL": "Editor guide",
            "HIDE_WAGTAIL_CORE_EDITOR_GUIDE": True,
        }
        if defaults is not None:
            self.defaults.update(defaults)

    def __getattr__(self, attr):
        if attr not in self.defaults:
            raise AttributeError(
                f"'{self.__class__.__name__}' object has no attribute '{attr}'"
            )

        django_settings = getattr(settings, "WAGTAIL_GUIDE_SETTINGS", {})
        return django_settings.get(attr, self.defaults[attr])


wagtail_guide_settings = WagtailGuideSettings()



from django.templatetags.static import static
from django.urls import re_path, reverse
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _
from wagtail import hooks
from wagtail.admin.menu import MenuItem

from . import views
from .settings import wagtail_guide_settings


@hooks.register("register_admin_urls")
def register_admin_urls():
    return [
        re_path(r"^editorguide/$", views.index, name="wagtaileditorguide"),
    ]


if wagtail_guide_settings.ADD_WAGTAIL_GUIDE_TO_HELP_MENU:

    @hooks.register("register_help_menu_item")
    def register_editor_guide_menu_item():
        return MenuItem(
            _(wagtail_guide_settings.WAGTAIL_GUIDE_MENU_LABEL),
            reverse("wagtaileditorguide"),
            classnames="icon icon-help",
            order=1000,
        )

else:

    @hooks.register("register_admin_menu_item")
    def register_editor_guide_menu_item():
        return MenuItem(
            _(wagtail_guide_settings.WAGTAIL_GUIDE_MENU_LABEL),
            reverse("wagtaileditorguide"),
            classnames="icon icon-help",
            order=1000,
        )


if wagtail_guide_settings.HIDE_WAGTAIL_CORE_EDITOR_GUIDE:

    @hooks.register("construct_help_menu")
    def construct_help_menu(request, menu_items):
        items_to_hide = ["https://guide.wagtail.org/"]
        menu_items[:] = [item for item in menu_items if item.url not in items_to_hide]
        return menu_items


@hooks.register("insert_global_admin_css", order=100)
def global_admin_css():
    """Add /static/css/wagtailguide.css to the wagtail admin area."""
    return format_html(
        '<link rel="stylesheet" href="{}">', static("css/wagtailguide.css")
    )



import os

PROJECT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
BASE_DIR = os.path.dirname(PROJECT_DIR)


SECRET_KEY = "not so secret"

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": "db.sqlite3",
    }
}

INSTALLED_APPS = [
    "wagtail.contrib.styleguide",
    "wagtail.contrib.routable_page",
    "wagtail.contrib.frontend_cache",
    "wagtail.contrib.settings",
    "wagtail.contrib.modeladmin",
    "wagtail.contrib.table_block",
    "wagtail.contrib.forms",
    "wagtail.embeds",
    "wagtail.sites",
    "wagtail.users",
    "wagtail.snippets",
    "wagtail.documents",
    "wagtail.images",
    "wagtail.admin",
    "wagtail",
    "taggit",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.sitemaps",
    "wagtail_guide",
]


MIDDLEWARE = [
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
]

ROOT_URLCONF = "wagtail_guide.tests.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
                "wagtail.contrib.settings.context_processors.settings",
            ],
        },
    },
]
WAGTAIL_SITE_NAME = "llama-savers"
USE_TZ = True


WAGTAILADMIN_BASE_URL = "http://localhost:8000"

WAGTAIL_GUIDE_SETTINGS = {
    "ADD_WAGTAIL_GUIDE_TO_HELP_MENU": False,
    "WAGTAIL_GUIDE_MENU_LABEL": "WG guide menu label",
    "HIDE_WAGTAIL_CORE_EDITOR_GUIDE": True,
}



from django.contrib.auth import get_user_model
from django.contrib.auth.models import Group
from django.test import TestCase
from django.urls import reverse
from wagtail.test.utils import WagtailTestUtils

from ..models import EditorGuide


class EditorGuideTest(TestCase, WagtailTestUtils):
    def setUp(self):
        super().setUp()
        self.login()
        User = get_user_model()
        editors_group = Group.objects.get(name="Editors")

        self.editor = User.objects.create_user(username="testuser", password="pass")
        self.editor.groups.add(editors_group)

    def test_admin(self):
        response = self.client.get(reverse("wagtailadmin_home"))
        self.assertEqual(response.status_code, 200)

    def test_guide_edit_links(self):
        response = self.client.get(reverse("wagtailadmin_home"))
        self.assertIn(
            '"name": "manage-editor-guide", "label": "Manage Editor Guide"',
            response.content.decode(),
        )

    def test_editor_view(self):
        response = self.client.get(reverse("wagtaileditorguide"))
        self.assertEqual(response.status_code, 200)

    def test_editor_view_null_message(self):
        # Check we see the no create message if no guide is added
        response = self.client.get(reverse("wagtaileditorguide"))
        self.assertContains(
            response,
            '<p class="help-block help-warning">An editor guide has not been\n'
            "created yet. Add one in Settings > Manage Editor Guide</p>",
            html=True,
        )

    def test_adding_a_guide(self):
        # Check we can see field data in the guide once added
        EditorGuide.objects.create(
            information_text="9999",
            sections=[
                ("heading", "A Heading"),
                ("heading", "Another heading"),
            ],
            site_id=1,
        )
        response = self.client.get(reverse("wagtaileditorguide"))
        self.assertContains(response, "A Heading")

    def test_permissions(self):
        # Unless the manage permission guide is added to the editor group,
        # An editor shouldn't be able to see the managle link in settings > manage guide
        self.client.logout()
        self.client.login(username="testuser", password="pass")
        response = self.client.get(reverse("wagtailadmin_home"))
        self.assertNotContains(
            response,
            '<a href="/admin/settings/wagtail_guide/editorguide/" class="icon icon-help">Manage Editor Guide</a>',
            html=True,
        )



from django.db import models
from modelcluster.models import ClusterableModel
from wagtail import blocks
from wagtail.admin.panels import FieldPanel
from wagtail.contrib.settings.models import BaseSiteSetting, register_setting
from wagtail.embeds.blocks import EmbedBlock
from wagtail.fields import StreamField
from wagtail.images.blocks import ImageChooserBlock


class ImageBlock(blocks.StructBlock):
    image = ImageChooserBlock()
    caption = blocks.CharBlock(required=False)

    class Meta:
        icon = "image"
        template = "wagtail_guide/streamfield/blocks/image_block.html"


class QuoteBlock(blocks.StructBlock):
    quote = blocks.CharBlock(classname="title")
    attribution = blocks.CharBlock(required=False)

    class Meta:
        icon = "openquote"
        template = "wagtail_guide/streamfield/blocks/quote_block.html"


class PullQuoteBlock(blocks.StructBlock):
    pull_quote = blocks.CharBlock(classname="title")

    class Meta:
        icon = "openquote"
        template = "wagtail_guide/streamfield/blocks/pull_quote_block.html"


class IframeBlock(blocks.StructBlock):
    title = blocks.CharBlock(required=False)
    source = blocks.URLBlock()

    class Meta:
        icon = "code"
        template = "wagtail_guide/streamfield/blocks/iframe_block.html"


class EmbedTitleBlock(blocks.StructBlock):
    title = blocks.CharBlock(required=False)
    embed = EmbedBlock()

    class Meta:
        icon = "media"
        template = "wagtail_guide/streamfield/blocks/embed_block.html"


class VideoBlock(blocks.StructBlock):
    video = EmbedBlock(required=False, label="Video URL")

    class Meta:
        icon = "media"
        template = "wagtail_guide/streamfield/blocks/video_block.html"
        label = "Video"


class GuideBlock(blocks.StreamBlock):
    heading = blocks.CharBlock(
        classname="full title",
        icon="title",
        template="wagtail_guide/streamfield/blocks/heading_block.html",
    )

    paragraph = blocks.RichTextBlock(
        features=[
            "h2",
            "h3",
            "h4",
            "h5",
            "h6",
            "bold",
            "italic",
            "link",
            "ul",
            "ol",
            "hr",
        ]
    )
    image = ImageBlock()
    quote = QuoteBlock()
    pull_quote = PullQuoteBlock()
    embed = EmbedTitleBlock()
    video = VideoBlock()

    class Meta:
        template = "wagtail_guide/streamfield/stream_block.html"


@register_setting(icon="help")
class EditorGuide(BaseSiteSetting, ClusterableModel):
    information_text = models.TextField(
        blank=True, help_text="Add a leading information paragraph explaining the guide"
    )
    sections = StreamField(GuideBlock(required=False), blank=True, use_json_field=True)

    panels = [FieldPanel("information_text"), FieldPanel("sections")]

    class Meta:
        verbose_name = "Manage Editor Guide"



from django.contrib import admin
from django.urls import include, path
from wagtail import urls as wagtail_urls
from wagtail.admin import urls as wagtailadmin_urls
from wagtail.documents import urls as wagtaildocs_urls

private_urlpatterns = [
    path("django-admin/", admin.site.urls),
    path("admin/", include(wagtailadmin_urls)),
    path("documents/", include(wagtaildocs_urls)),
]

# Public URLs that are meant to be cached.
urlpatterns = []

urlpatterns = (
    private_urlpatterns
    + urlpatterns
    + [
        # Add Wagtail URLs at the end.
        # Wagtail cache-control is set on the page models's serve methods.
        path("", include(wagtail_urls)),
    ]
)



#!/usr/bin/env python
"""
Installs the Wagtail Guide plugin.
"""

from os import path

from setuptools import find_packages, setup

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


setup(
    name="wagtail_guide",
    version="2.0.0",
    description="Adds functionality to add and edit a CMS guide page for editors.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kevinhowbrook/wagtailguide",
    author="Kevin Howbrook - Torchbox",
    author_email="kevin.howbrook@torchbox.com",
    license="MIT",
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    install_requires=[
        "wagtail>=4.1",
    ],
    testing_extras=[
        "coverage>=6.4.1",
    ],
)



# Generated by Django 2.1.8 on 2019-05-18 11:38

import django.db.models.deletion
from django.db import migrations, models

import wagtail.blocks as wagtail_blocks
import wagtail.fields as wagtail_fields

import wagtail.embeds.blocks
import wagtail.images.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("wagtailcore", "0041_group_collection_permissions_verbose_name_plural"),
    ]

    operations = [
        migrations.CreateModel(
            name="EditorGuide",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "information_text",
                    models.TextField(
                        blank=True,
                        help_text="Add a leading information paragraph explaining the guide",
                    ),
                ),
                (
                    "sections",
                    wagtail_fields.StreamField(
                        [
                            (
                                "heading",
                                wagtail_blocks.CharBlock(
                                    classname="full title",
                                    icon="title",
                                    template="wagtail_guide/streamfield/blocks/heading_block.html",
                                ),
                            ),
                            (
                                "paragraph",
                                wagtail_blocks.RichTextBlock(
                                    features=[
                                        "h2",
                                        "h3",
                                        "h4",
                                        "h5",
                                        "h6",
                                        "bold",
                                        "italic",
                                        "link",
                                        "ul",
                                        "ol",
                                        "hr",
                                    ]
                                ),
                            ),
                            (
                                "image",
                                wagtail_blocks.StructBlock(
                                    [
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(),
                                        ),
                                        (
                                            "caption",
                                            wagtail_blocks.CharBlock(required=False),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                "quote",
                                wagtail_blocks.StructBlock(
                                    [
                                        (
                                            "quote",
                                            wagtail_blocks.CharBlock(classname="title"),
                                        ),
                                        (
                                            "attribution",
                                            wagtail_blocks.CharBlock(required=False),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                "pull_quote",
                                wagtail_blocks.StructBlock(
                                    [
                                        (
                                            "pull_quote",
                                            wagtail_blocks.CharBlock(classname="title"),
                                        )
                                    ]
                                ),
                            ),
                            (
                                "embed",
                                wagtail_blocks.StructBlock(
                                    [
                                        (
                                            "title",
                                            wagtail_blocks.CharBlock(required=False),
                                        ),
                                        ("embed", wagtail.embeds.blocks.EmbedBlock()),
                                    ]
                                ),
                            ),
                            (
                                "video",
                                wagtail_blocks.StructBlock(
                                    [
                                        (
                                            "video",
                                            wagtail.embeds.blocks.EmbedBlock(
                                                label="Video URL", required=False
                                            ),
                                        )
                                    ]
                                ),
                            ),
                        ],
                        blank=True,
                    ),
                ),
                (
                    "site",
                    models.OneToOneField(
                        editable=False,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="wagtailcore.Site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Manage Editor Guide",
            },
        ),
    ]
